==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/UserImportRequestData.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserImportRequestDataAction;
import com.okta.sdk.resource.model.UserImportRequestDataAppUser;
import com.okta.sdk.resource.model.UserImportRequestDataContext;
import com.okta.sdk.resource.model.UserImportRequestDataUser;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserImportRequestData
 */
@JsonPropertyOrder({ UserImportRequestData.JSON_PROPERTY_ACTION, UserImportRequestData.JSON_PROPERTY_APP_USER,
        UserImportRequestData.JSON_PROPERTY_CONTEXT, UserImportRequestData.JSON_PROPERTY_USER })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserImportRequestData implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ACTION = "action";
    private UserImportRequestDataAction action;

    public static final String JSON_PROPERTY_APP_USER = "appUser";
    private UserImportRequestDataAppUser appUser;

    public static final String JSON_PROPERTY_CONTEXT = "context";
    private UserImportRequestDataContext context;

    public static final String JSON_PROPERTY_USER = "user";
    private UserImportRequestDataUser user;

    public UserImportRequestData() {
    }

    public UserImportRequestData action(UserImportRequestDataAction action) {

        this.action = action;
        return this;
    }

    /**
     * Get action
     *
     * @return action
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserImportRequestDataAction getAction() {
        return action;
    }

    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAction(UserImportRequestDataAction action) {
        this.action = action;
    }

    public UserImportRequestData appUser(UserImportRequestDataAppUser appUser) {

        this.appUser = appUser;
        return this;
    }

    /**
     * Get appUser
     *
     * @return appUser
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_APP_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserImportRequestDataAppUser getAppUser() {
        return appUser;
    }

    @JsonProperty(JSON_PROPERTY_APP_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAppUser(UserImportRequestDataAppUser appUser) {
        this.appUser = appUser;
    }

    public UserImportRequestData context(UserImportRequestDataContext context) {

        this.context = context;
        return this;
    }

    /**
     * Get context
     *
     * @return context
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserImportRequestDataContext getContext() {
        return context;
    }

    @JsonProperty(JSON_PROPERTY_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContext(UserImportRequestDataContext context) {
        this.context = context;
    }

    public UserImportRequestData user(UserImportRequestDataUser user) {

        this.user = user;
        return this;
    }

    /**
     * Get user
     *
     * @return user
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserImportRequestDataUser getUser() {
        return user;
    }

    @JsonProperty(JSON_PROPERTY_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUser(UserImportRequestDataUser user) {
        this.user = user;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserImportRequestData userImportRequestData = (UserImportRequestData) o;
        return Objects.equals(this.action, userImportRequestData.action)
                && Objects.equals(this.appUser, userImportRequestData.appUser)
                && Objects.equals(this.context, userImportRequestData.context)
                && Objects.equals(this.user, userImportRequestData.user);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(action, appUser, context, user);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserImportRequestData {\n");
        sb.append("    action: ").append(toIndentedString(action)).append("\n");
        sb.append("    appUser: ").append(toIndentedString(appUser)).append("\n");
        sb.append("    context: ").append(toIndentedString(context)).append("\n");
        sb.append("    user: ").append(toIndentedString(user)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/UserImportRequestData.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserImportRequestDataAction;
import com.okta.sdk.resource.model.UserImportRequestDataAppUser;
import com.okta.sdk.resource.model.UserImportRequestDataContext;
import com.okta.sdk.resource.model.UserImportRequestDataUser;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserImportRequestData
 */
@JsonPropertyOrder({ UserImportRequestData.JSON_PROPERTY_ACTION, UserImportRequestData.JSON_PROPERTY_APP_USER,
        UserImportRequestData.JSON_PROPERTY_CONTEXT, UserImportRequestData.JSON_PROPERTY_USER })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UserImportRequestData implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ACTION = "action";
    private UserImportRequestDataAction action;

    public static final String JSON_PROPERTY_APP_USER = "appUser";
    private UserImportRequestDataAppUser appUser;

    public static final String JSON_PROPERTY_CONTEXT = "context";
    private UserImportRequestDataContext context;

    public static final String JSON_PROPERTY_USER = "user";
    private UserImportRequestDataUser user;

    public UserImportRequestData() {
    }

    public UserImportRequestData action(UserImportRequestDataAction action) {

        this.action = action;
        return this;
    }

    /**
     * Get action
     *
     * @return action
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserImportRequestDataAction getAction() {
        return action;
    }

    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAction(UserImportRequestDataAction action) {
        this.action = action;
    }

    public UserImportRequestData appUser(UserImportRequestDataAppUser appUser) {

        this.appUser = appUser;
        return this;
    }

    /**
     * Get appUser
     *
     * @return appUser
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_APP_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserImportRequestDataAppUser getAppUser() {
        return appUser;
    }

    @JsonProperty(JSON_PROPERTY_APP_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAppUser(UserImportRequestDataAppUser appUser) {
        this.appUser = appUser;
    }

    public UserImportRequestData context(UserImportRequestDataContext context) {

        this.context = context;
        return this;
    }

    /**
     * Get context
     *
     * @return context
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserImportRequestDataContext getContext() {
        return context;
    }

    @JsonProperty(JSON_PROPERTY_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContext(UserImportRequestDataContext context) {
        this.context = context;
    }

    public UserImportRequestData user(UserImportRequestDataUser user) {

        this.user = user;
        return this;
    }

    /**
     * Get user
     *
     * @return user
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserImportRequestDataUser getUser() {
        return user;
    }

    @JsonProperty(JSON_PROPERTY_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUser(UserImportRequestDataUser user) {
        this.user = user;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserImportRequestData userImportRequestData = (UserImportRequestData) o;
        return Objects.equals(this.action, userImportRequestData.action)
                && Objects.equals(this.appUser, userImportRequestData.appUser)
                && Objects.equals(this.context, userImportRequestData.context)
                && Objects.equals(this.user, userImportRequestData.user);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(action, appUser, context, user);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserImportRequestData {\n");
        sb.append("    action: ").append(toIndentedString(action)).append("\n");
        sb.append("    appUser: ").append(toIndentedString(appUser)).append("\n");
        sb.append("    context: ").append(toIndentedString(context)).append("\n");
        sb.append("    user: ").append(toIndentedString(user)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
